@extends('admin.layouts.main')
@section('content')

    <div class="container-fluid">
        <div class="row page-titles">
            <div class="col-md-5 align-self-center">
                <h4 class="text-themecolor">Add Product</h4>
            </div>
            <div class="col-md-7 align-self-center text-right">
                <div class="d-flex justify-content-end align-items-center">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Dashboard</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.product.index')}}">All Products</a></li>
                        <li class="breadcrumb-item active">Create</li>
                    </ol>
                </div>
            </div>

        </div>
        <div class="form-group row">
            <div class="col-sm-12">
                @if ($errors->any())
                    <div class="alert alert-danger">
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </div>
                @endif
            </div>
            <div class="col-sm-12">
                @if (session()->has('message'))
                    <div class="alert alert-success">
                        {{session('message')}}
                    </div>
                @endif
            </div>
            <div class="col-sm-12">
                @if (session()->has('hasError'))
                    <div class="alert alert-danger">
                        {{session('hasError')}}
                    </div>
                @endif
            </div>
        </div>
        <div class="row">
            <div class="col-sm-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title text-primary">Add Product</h5>
                        <form class="form-material form-horizontal" id="product_form" onsubmit="check()"
                              method="POST" enctype="multipart/form-data">
                            @csrf
                            <div class="row">
                                <div class="form-group col-sm-6">
                                    <label for="bike_color">Product Name
                                    </label>

                                    <input type="text" name="name" id="name" class="form-control"
                                           required>
                                </div>
                                <div class="form-group col-sm-3">
                                    <label for="bike_color">Product Quantity
                                    </label>

                                    <input type="number" name="quantity" id="quantity" class="form-control"
                                           required>
                                </div>
                                <div class="form-group col-sm-3">
                                    <label for="bike_color">Product Unit
                                    </label>
                                    <select name="unit" class="form-control" id="unit" required>
                                        <option value="">Select Unit</option>
                                        <option value="Gram">Gram</option>
                                        <option value="Kilo">Kilo</option>
                                        <option value="Liter">Liter</option>
                                        <option value="Dozen">Dozen</option>
                                        <option value="Piece">Piece</option>
                                    </select>

                                </div>
                                <div class="form-group col-sm-6">
                                    <label>Choose Category:
                                        <input list="categories" id="category" class="form-control" name="category" autocomplete="off" required/></label>
                                    <datalist id="categories">

                                    </datalist>
                                </div>
                                <div class="form-group col-sm-6">
                                    <label>Choose SubCategory:
                                        <input list="subcategories" id="sub_category" class="form-control" name="sub_category" autocomplete="off" required/></label>
                                    <datalist id="subcategories">

                                    </datalist>
                                </div>
                                <div class="form-group col-sm-4">
                                    <label for="bike_color">Product Cost
                                    </label>

                                    <input type="number" name="cost" id="cost" class="form-control"
                                           required>
                                </div>
                                <div class="form-group col-sm-4">
                                    <label for="bike_color">Profit Percentage
                                    </label>

                                    <input type="number" name="profit_percentage" id="profit_percentage" class="form-control"
                                           required>
                                </div>

                                <div class="form-group col-sm-4">
                                    <label for="bike_color">Discount Percentage
                                    </label>

                                    <input type="number" name="discount_percentage" id="discount_percentage" class="form-control"
                                           required>
                                </div>

                                <div class="form-group col-sm-6">
                                    <label for="bike_color">Stock
                                    </label>

                                    <input type="number" name="stock" id="stock" class="form-control"
                                           required>
                                </div>
                                <div class="form-group col-sm-6">
                                    <label for="bike_color">Tags
                                    </label>

                                    <input type="text" name="tags" id="tags" class="form-control"
                                           required>
                                </div>
                                <div class="form-group col-sm-12">
                                    <label for="bike_color">Description
                                    </label>

                                    <textarea class="form-control" id="description" rows="3" required></textarea>
                                </div>

                            </div>

                            <div class="row">
                                <div class="form-group col-sm-6">

                                    <div class="card">
                                        <div class="card-body">
                                            <label for="image">Main Image</label>
                                            <input type="file" accept="image/*" id="image" class="dropify"
                                                   data-max-file-size="2M" name="image" required/>
                                        </div>
                                    </div>

                                </div>
                                <div class="form-group col-sm-6">

                                    <div class="card">
                                        <div class="card-body">
                                            <label for="id_card_front">Image 1</label>
                                            <input type="file" accept="image/*" id="image1" class="dropify"
                                                   data-max-file-size="2M" name="image1" required/>
                                        </div>
                                    </div>

                                </div>

                                <div class="form-group col-sm-6">

                                    <div class="card">
                                        <div class="card-body">
                                            <label for="id_card_back">Image 2</label>
                                            <input type="file" accept="image/*" id="image2" class="dropify"
                                                   data-max-file-size="2M" name="image2" required/>
                                        </div>
                                    </div>

                                </div>
                                <div class="col-sm-6">

                                </div>

                                <div class="col-sm-12 text-center">
                                    <button type="submit" class="btn btn-success">Submit</button>

                                </div>
                            </div>


                        </form>
                    </div>
                </div>
            </div>
        </div>


    </div>
@endsection
@section('custom-script')
    <script type="text/javascript">
        var starCountRef = firebase.database().ref('Products');
        starCountRef.once('value').then(function(snapshot){

            snapshot.forEach(function(childNodes){

                $('#categories').append('<option value="'+childNodes.key+'">')
            });
        });


        $('#category').on('change',function () {
            var category=$('#category').val();
            firebase.database().ref('Products/'+category).once('value').then(function(snapshot){

                snapshot.forEach(function(childNodes){

                    $('#subcategories').append('<option value="'+childNodes.key+'">')
                });
            });


        });

        function upload_image(image,image_name) {
            return new Promise((resolve, reject)=>{
                var storageRef=firebase.storage().ref('Products_Images/'+image_name);
                //upload image to selected storage reference
                //make sure you pass image here
                var uploadTask=storageRef.put(image);
                //to get the state of image uploading....
                uploadTask.on('state_changed',function(snapshot){
                    //get task progress by following code
                    var progress=(snapshot.bytesTransferred/snapshot.totalBytes)*100;
                    console.log("upload is "+progress+" done");
                },function(error){
                    //handle error here
                    reject({
                        status:false,
                        message:'Error Occurred while image uploading'
                    })
                },function(){
                    //handle successfull upload here..
                    uploadTask.snapshot.ref.getDownloadURL().then(function(downloadURL){
                        resolve({
                            status:true,
                            url:downloadURL
                        });

                    });
                });
            });

        }




        function upload(){
            return new Promise((resolve, reject)=>{
                //images URL
                var image_url="";
                var image1_url="";
                var image2_url="";




                //get your image
                var image=document.getElementById('image').files[0];
                var image1=document.getElementById('image1').files[0];
                var image2=document.getElementById('image2').files[0];

                //get your blog text

                let name=$('#name').val();
                let quantity=$('#quantity').val();
                let unit=$('#unit').val();
                let category=$('#category').val();
                let sub_category=$('#sub_category').val();
                let cost=parseInt($('#cost').val());
                let discount_percentage=parseInt($('#discount_percentage').val());
                let profit_percentage=parseInt($('#profit_percentage').val());
                let stock=$('#stock').val();
                let tags=$('#tags').val();
                let description=$('#description').val();



                let selling_price=Math.round(parseFloat(cost+((profit_percentage/100)*cost)));
                let discount_price=Math.round(parseFloat(selling_price-((discount_percentage/100)*selling_price)));

                discount_price=discount_price.toString();
                //get image name
                var image_name=Math.floor(Math.random() * 100001)+image.name;
                var image1_name=Math.floor(Math.random() * 100001)+image1.name;
                var image2_name=Math.floor(Math.random() * 100001)+image2.name;


                upload_image(image,image_name).then(response=>{

                    image_url=response.url;
                    upload_image(image1,image1_name).then(response =>{

                        image1_url=response.url;
                        upload_image(image2,image2_name).then(response =>{


                            image2_url=response.url;
                            var id = Date.now();
                            firebase.database().ref('Products/'+category+'/'+sub_category+'/'+id).set({
                                product_name:name,
                                product_unit:quantity+" "+unit,
                                product_category:category,
                                product_sub_category:sub_category,
                                product_cost:cost,
                                product_profit_percent:profit_percentage,
                                product_discount_percent:discount_percentage,
                                product_discount_price:discount_price,
                                product_selling_price:selling_price,
                                product_stock:stock,
                                tags:tags,
                                product_description:description,
                                main_photo:image_url,
                                photo_1:image1_url,
                                photo_2:image2_url,
                                ratings:{average_rating:"0.0",total_ratings:"0"}

                            },function(error){
                                if(error){
                                    reject(error.message);
                                }else{

                                    document.getElementById('product_form').reset();
                                    $(".dropify-clear").trigger("click");

                                    resolve({status:true});

                                }
                            });



                        }).catch(error=>{
                            reject(error.message);
                        });



                    }).catch(error=>{
                        reject(error.message);
                    });

                }).catch(error=>{
                    reject(error.message);
                });

            }).catch(error=>{
                reject(error.message);
            });



        }




        function check() {
            event.preventDefault();
            var valid = document.getElementById("product_form").checkValidity();
            if (valid) {
                swal.fire({
                    imageUrl:"https://i.pinimg.com/originals/78/e8/26/78e826ca1b9351214dfdd5e47f7e2024.gif",
                    title: 'Uploading Data!',
                    text: 'Please Wait...',
                    showConfirmButton: false,
                    allowOutsideClick : false
                });
                upload().then(response => {
                    if (response.status === true) {
                        swal.close();
                        swal.fire({
                            title: "Success!",
                            text: "Product Added!",
                            icon: "success",
                            button: "Close!",
                        });

                    }
                }).catch(error => {
                    console.log(error);
                });
            }

        }


        $(document).ready(function () {


        });
    </script>
@endsection